<?php
if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly
}

if ( ! class_exists( 'WPSC_Import_Functions' ) ) :
  
  final class WPSC_Import_Functions {
    
    function get_wpsc_categories(){
      $categories = get_terms([
        'taxonomy' => 'wpsc_categories',
        'hide_empty' => false,
      ]);
      return $categories;
    }
    
    function get_wpsp_categories(){
      global $wpdb;
      $wpsp_categories = $wpdb->get_results("select * from {$wpdb->prefix}wpsp_catagories");
      return $wpsp_categories;
    }
    
    function get_wpsc_status(){
      $statuses = get_terms([
        'taxonomy' => 'wpsc_statuses',
        'hide_empty'=>false,
      ]);
      return $statuses;
    }
    
    function get_wpsp_status(){
      global $wpdb;
      $statuses = $wpdb->get_results( "select * from {$wpdb->prefix}wpsp_custom_status" );
      return $statuses;
    }
    
    function get_wpsc_priorities(){
      
      $priorities = get_terms([
        'taxonomy'=>'wpsc_priorities',
        'hide_empty' => false,
      ]);
      return $priorities;
    }
    
    function get_wpsp_priorities(){
      global $wpdb;
      $wpsp_priority = $wpdb->get_results("select * from {$wpdb->prefix}wpsp_custom_priority");
      return $wpsp_priority;
    }
    
    function get_wpsc_custom_fields(){
    
      $custom_fields = get_terms([
        'taxonomy' => 'wpsc_ticket_custom_fields',
        'hide_empty' => false,
        'orderby'    => 'meta_value_num',
        'meta_key'	 => 'wpsc_tf_load_order',
        'order'    	 => 'ASC',
        'meta_query' => array(
          array(
            'key'       => 'agentonly',
       			'value'     => array(0,1),
       			'compare'   => 'IN'
          )
        ),
        ]);
        
        return $custom_fields;
    }
    
    function get_wpsp_form_fields(){
      global $wpdb;
      $form_fields = $wpdb->get_results("select * from {$wpdb->prefix}wpsp_ticket_form_order ORDER BY load_order");
      return $form_fields;
    }
    
    function get_wpsp_custom_fields(){
      global $wpdb;
      $wpsp_custom_fields = $wpdb->get_results("select * from {$wpdb->prefix}wpsp_custom_fields");
      return $wpsp_custom_fields;
    }
    
    function wpsc_get_all_agents(){
      $agents = get_terms([
        'taxonomy'   => 'wpsc_agents',
        'hide_empty' => false,
        'meta_query' => array(
          array(
            'key'       => 'agentgroup',
            'value'     => '0',
            'compare'   => '='
          )
        )
      ]);
      return $agents;
    }
    
    function get_user_agent_id($user_id){
      // global $current_user;
      $agents = get_terms([
        'taxonomy'   => 'wpsc_agents',
        'hide_empty' => false,
        'meta_query' => array(
          'relation' => 'AND',
          array(
            'key'       => 'user_id',
            'value'     => $user_id,
            'compare'   => '='
          )
        ),
      ]);
      if($agents){
        return $agents[0]->term_id;
      } else {
        return 0;
      }
    }
    
    function submit_thread($args){
      
      global $wpdb;
      
      $thread_id = wp_insert_post(
        array(
          'post_type'    => 'wpsc_ticket_thread',
          'post_content' => $args['reply_body'],
          'post_status'  => 'publish',
          'post_date_gmt'    => $args['create_time']
        )
      );
      add_post_meta( $thread_id, 'ticket_id', $args['ticket_id'] );
      add_post_meta( $thread_id, 'thread_type', $args['thread_type'] );
      $customer_name =  isset($args['customer_name']) ? $args['customer_name'] : '';
      add_post_meta( $thread_id, 'customer_name', $customer_name );
      $customer_email =  isset($args['customer_email']) ? $args['customer_email'] : '';
      add_post_meta( $thread_id, 'customer_email', $customer_email );
      $attachments =  isset($args['attachments']) ? $args['attachments'] : array();
      add_post_meta( $thread_id, 'attachments', $attachments );
      $ticket_id =  isset($args['ticket_id']) ? $args['ticket_id'] : 0;
      return $thread_id;
      
    }
    
    // Register Post type and texonomies
    public function register_post_type() {
      
      // Register Conditional Agent Assign texonomy
			$args = array(
          'public'             => false,
          'rewrite'            => false
      );
      register_taxonomy( 'wpsc_caa', 'wpsc_ticket', $args );
    }
    
    public function import_all_conditions($en_conditions){
      
      global $wpdb;
      foreach ($en_conditions as $key => $value) {
  
        if ($key=='cat_id') {
            
          $wpsc_category = get_term_by('slug','ticket_category','wpsc_ticket_custom_fields');
          $category_id = $wpsc_category->term_id;
          $category = implode(',',$value);
          $wpsp_category = $wpdb->get_results("select * from {$wpdb->prefix}wpsp_catagories where id IN (".$category. ")");
          
          foreach ($wpsp_category as $wpsp_category) {
            $category_data = get_term_by('name',$wpsp_category->name,'wpsc_categories');
            $condition  = $category_data->term_id;
          
            $cond_val= array(
              "field" => $category_id,
              "compare" => "match",
              "cond_val" => $condition
            );
            $condition_data[] = json_encode($cond_val);
          }
        
        } elseif ($key == 'status_id') {
          
          $wpsc_status = get_term_by('slug','ticket_status','wpsc_ticket_custom_fields');
          $status_id = $wpsc_status->term_id;
            
          $status = implode(',',$value);
          $wpsp_statuses = $wpdb->get_results("select * from {$wpdb->prefix}wpsp_custom_status where id IN (".$status.")");
          
          foreach ($wpsp_statuses as $wpsp_status) {
            
            $status_data = get_term_by('name',$wpsp_status->name,'wpsc_statuses');
            $cond = array(
              "field" => $status_id,
              "compare" => "match",
              "cond_val" => $status_data->term_id
            );
            $condition_data[] = json_encode($cond);
          }
        
        } elseif ($key == 'priority_id') {
          
          $wpsc_priority = get_term_by('slug','ticket_priority','wpsc_ticket_custom_fields');
          $priority_id = $wpsc_priority->term_id;
            
          $priority = implode(',',$value);
          $wpsp_priorities = $wpdb->get_results("select * from {$wpdb->prefix}wpsp_custom_priority WHERE id IN (".$priority. ")");
          
          foreach ($wpsp_priorities as $wpsp_priority) {
            
            $priority_data = get_term_by('name',$wpsp_priority->name,'wpsc_priorities');
            $condition_val = array(
              "field" => $priority_id,
              "compare" => "match",
              "cond_val" => $priority_data->term_id
            );
            $condition_data[] = json_encode($condition_val);
            
          }
        
        } elseif ($key == 'subject') {
          
          $ticket_subject = get_term_by('slug','ticket_subject','wpsc_ticket_custom_fields');
          
          foreach ($value as $subject) {
            $condition_val = array(
              "field" => $ticket_subject->term_id,
              "compare" => "contain",
              "cond_val" => $subject
            );
            $condition_data[] = json_encode($condition_val);
          }
          
        } else {
          
          $c_fields = $wpdb->get_results("select * from {$wpdb->prefix}wpsp_custom_fields WHERE id =".$key."");
          
          foreach ($c_fields as $c_field) {

            if ($c_field->field_type =='2' || $c_field->field_type ='3' || $c_field->field_type ='4') {
              $matches = "match";
            }
            
            $matches = "contain";
            $field = get_term_by('name',$c_field->label,'wpsc_ticket_custom_fields');
          }
          
          foreach ($value as $custom_field) {
            $condition_val = array(
              "field" => $field->term_id,
              "compare" => $matches,
              "cond_val" => $custom_field
            );
            $condition_data[] = json_encode($condition_val);
          }
        
        }
      }
      
      $data = implode(',',$condition_data);
      return $data;
    }
    
    public function get_user_register_post_type() {
      
      // Register Conditional Agent Assign texonomy
      $args = array(
          'public'             => false,
          'rewrite'            => false
      );
      register_taxonomy( 'wpsc_usergroup_data', 'wpsc_ticket', $args );
    }
    
    public function get_time_local_to_utc($time){
      return get_gmt_from_date($time);
    }
    
    public function chmod_r($Path) {
      
      $dp = opendir($Path);
      
      while($File = readdir($dp)) {
        if($File != "." AND $File != "..") {
          if(is_dir($File)){
            chmod($File, 0750);
            chmod_r($Path."/".$File);
          }else{
            chmod($Path."/".$File, 0644);
          }
        }
      }
      closedir($dp);
    }	
    
  }  
  endif;

  $GLOBALS['wpscimportfunction'] =  new WPSC_Import_Functions();