<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $current_user,$wpdb,$wpsupportplus,$wpscfunction,$wpscimportfunction;

if( !$current_user->has_cap('manage_options') ) exit();

/**
 * Get Email notification General Settings
*/

$email_notification   = get_option('wpsp_email_notification') ? get_option('wpsp_email_notification') : array();
$ignore_emails = array();

if(isset($email_notification['from_name'])){
  update_option('wpsc_en_from_name',$email_notification['from_name']);
}
 
if(isset($email_notification['from_email'])){
  update_option('wpsc_en_from_email',$email_notification['from_email']);
}
 
if(isset($email_notification['reply_to'])){
  update_option('wpsc_en_reply_to',$email_notification['reply_to']);
}
 
if(isset($email_notification['ignore_emails'])){  
	$ignore_emails[] = $email_notification['ignore_emails'];
  update_option('wpsc_en_ignore_emails',$ignore_emails);
}

$wpsp_en_notification = get_option('wpsp_en_notification') ? get_option('wpsp_en_notification') : array();
$notification_types = $wpscfunction->get_email_notification_types();
$agent_role = get_option('wpsc_agent_role');

$email_templates = get_terms([
  'taxonomy'   => 'wpsc_en',
  'hide_empty' => false,
  'orderby'    => 'ID',
  'order'      => 'ASC',
  ]);

if($email_templates){
  foreach ($email_templates as $email_template) {
		delete_term_meta($email_template->term_id,'wpsc_en');
    wp_delete_term( $email_template->term_id,'wpsc_en');
  }
}

foreach ($wpsp_en_notification as $en_notification) {    
	
	$term = wp_insert_term($en_notification['title'], 'wpsc_en');

	if(!is_wp_error($term) && isset($term['term_id'])){
		
		if ($en_notification['type'] == 'crt_tkt' ){
			add_term_meta ($term['term_id'], 'type', 'new_ticket');
		} elseif ($en_notification['type'] == 'rep_tkt' ) {
			add_term_meta ($term['term_id'], 'type', 'ticket_reply');
		} elseif ($en_notification['type'] == 'cng_sts' ) {
			add_term_meta ($term['term_id'], 'type', 'change_status');
		} elseif ($en_notification['type'] == 'asgn_agnt') {
			add_term_meta ($term['term_id'], 'type', 'assign_agent');
		} elseif ( $en_notification['type'] == 'del_tkt') {
			add_term_meta ($term['term_id'], 'type', 'delete_ticket');
		} elseif ( $en_notification['type'] == 'note_tkt') {
			add_term_meta ($term['term_id'], 'type', 'private_note');
		}
    
		add_term_meta ($term['term_id'], 'subject', $en_notification['subject']);
		add_term_meta ($term['term_id'], 'body', $en_notification['description']);
      
		$recipients=array();
		foreach ($en_notification['recipients'] as $recipient) {
        
			if($recipient == 'administrator'){
				$recipients[]= 1;
			}
        
			if($recipient == 'customer'){
				$recipients[]='customer';
			}
    
			if($recipient == 'agent'){
				$recipients[]='assigned_agent';
      }
        
			if($recipient == 'all_agents'){
				$recipients[]='2';
			}

			if($recipient == 'supervisor'){
        $recipients[]='3';
      }
    }
      
		add_term_meta($term['term_id'], 'recipients', $recipients);
		add_term_meta($term['term_id'], 'extra_recipients', '');
		
		$condition_data = array();
		
		if(!isset($en_notification['condition'])){
			add_term_meta ($term['term_id'], 'conditions', '');
		} else{
			$data = $wpscimportfunction->import_all_conditions($en_notification['condition']);
			add_term_meta($term['term_id'],'conditions','['.$data.']');
		}
	}
} 